Processor.App.ArticleUtils.article\_extractor
=============================================

.. automodule:: Processor.App.ArticleUtils.article_extractor

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      ArticleExtractor
   
   

   
   
   



